@@ -62,6 +62,15 @@ void	config(int argc, char **argv)
 			{
 				dbOutPort = htons(atoi(pnt));
 			}
+                        else if (!memcmp (buff, "MONITOR_PORT", 12))
+                        {
+                                MonitorPort = htons(atoi(pnt));
+                        }
+                        else if (!memcmp (buff, "MONITOR_DOMAIN_NAME", 19))
+                        {
+                                memset (MonitorDomainName, 0x00, 128);
+                                memcpy (MonitorDomainName, pnt, strlen(pnt));
+                        }
                         else if (!memcmp (buff, "SERVER_NAME", 11))
                         {
 				len = strlen(pnt);
