@@ -3,13 +3,20 @@
 
 #define		MAX_SHM	20
 
+/* reqType      */
+#define         NoEntry         0x00
+#define         ReqConnect      0x01
+#define         Ack             0x02
+#define         Nak             0x03            /* Busy */
+#define         ReqEnd          0xff
+
 
 struct  shm_form {
         unsigned char    type;          /* 0x00 not use         */
                                         /* 0x01 リクエスト　    */
                                         /* 0x02 リプライ        */
                                         /* 0x03 未登録          */
-                                        /* 0x04 ポート登録      */
+                                        /* 0x04 		*/
                                         /* 0xff 削除            */
         char    protocol;
         char    dstRep[8];
@@ -19,6 +26,7 @@ struct  shm_form {
         char    srcCall[8];
         in_port_t       srcPort;
         struct  in_addr srcIP;
+	unsigned char	PacketID[2];
 };
 
 struct	shm_form_t
